Source-Changes-HG archive

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index][Old Index]

[src/trunk]: src/sys/arch More setttb() -> cpu_setttb() for readability & con...



details:   https://anonhg.NetBSD.org/src/rev/658cc755f35f
branches:  trunk
changeset: 750363:658cc755f35f
user:      uebayasi <uebayasi%NetBSD.org@localhost>
date:      Mon Dec 28 03:22:19 2009 +0000

description:
More setttb() -> cpu_setttb() for readability & consistency.  Missing instances
pointed out by tsutsui@ & nonaka@, thanks.

diffstat:

 sys/arch/acorn32/acorn32/rpc_machdep.c           |  8 ++++----
 sys/arch/acorn32/eb7500atx/eb7500atx_machdep.c   |  8 ++++----
 sys/arch/cats/cats/cats_machdep.c                |  8 ++++----
 sys/arch/evbarm/g42xxeb/g42xxeb_machdep.c        |  4 ++--
 sys/arch/evbarm/ixm1200/ixm1200_machdep.c        |  6 +++---
 sys/arch/evbarm/lubbock/lubbock_machdep.c        |  6 +++---
 sys/arch/iyonix/iyonix/iyonix_machdep.c          |  6 +++---
 sys/arch/netwinder/netwinder/netwinder_machdep.c |  6 +++---
 sys/arch/shark/ofw/ofw.c                         |  8 ++++----
 sys/arch/zaurus/zaurus/machdep.c                 |  6 +++---
 10 files changed, 33 insertions(+), 33 deletions(-)

diffs (291 lines):

diff -r fe44dd9102ac -r 658cc755f35f sys/arch/cats/cats/cats_machdep.c
--- a/sys/arch/cats/cats/cats_machdep.c Mon Dec 28 02:35:20 2009 +0000
+++ b/sys/arch/cats/cats/cats_machdep.c Mon Dec 28 03:22:19 2009 +0000
@@ -1,4 +1,4 @@
-/*     $NetBSD: cats_machdep.c,v 1.68 2009/11/27 03:23:05 rmind Exp $  */
+/*     $NetBSD: cats_machdep.c,v 1.69 2009/12/28 03:22:19 uebayasi Exp $       */
 
 /*
  * Copyright (c) 1997,1998 Mark Brinicombe.
@@ -40,7 +40,7 @@
  */
 
 #include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: cats_machdep.c,v 1.68 2009/11/27 03:23:05 rmind Exp $");
+__KERNEL_RCSID(0, "$NetBSD: cats_machdep.c,v 1.69 2009/12/28 03:22:19 uebayasi Exp $");
 
 #include "opt_ddb.h"
 #include "opt_modular.h"
@@ -695,7 +695,7 @@
         */
 #ifdef VERBOSE_INIT_ARM
        /* checking sttb address */
-       printf("setttb address = %p\n", cpufuncs.cf_setttb);
+       printf("cpu_setttb address = %p\n", cpu_setttb);
 
        printf("kernel_l1pt=0x%08x old = 0x%08x, phys = 0x%08x\n",
                        ((uint*)kernel_l1pt.pv_va)[0xf00],
@@ -732,7 +732,7 @@
        fcomcndetach();
 #endif
        
-       setttb(kernel_l1pt.pv_pa);
+       cpu_setttb(kernel_l1pt.pv_pa);
        cpu_tlb_flushID();
        cpu_domains(DOMAIN_CLIENT << (PMAP_DOMAIN_KERNEL*2));
        /*
diff -r fe44dd9102ac -r 658cc755f35f sys/arch/evbarm/g42xxeb/g42xxeb_machdep.c
--- a/sys/arch/evbarm/g42xxeb/g42xxeb_machdep.c Mon Dec 28 02:35:20 2009 +0000
+++ b/sys/arch/evbarm/g42xxeb/g42xxeb_machdep.c Mon Dec 28 03:22:19 2009 +0000
@@ -1,4 +1,4 @@
-/*     $NetBSD: g42xxeb_machdep.c,v 1.20 2009/12/26 16:01:24 uebayasi Exp $ */
+/*     $NetBSD: g42xxeb_machdep.c,v 1.21 2009/12/28 03:22:20 uebayasi Exp $ */
 
 /*
  * Copyright (c) 2002, 2003, 2004, 2005  Genetec Corporation.  
@@ -494,7 +494,7 @@
         * RedBoot's first level page table is at 0xa0004000.  There
         * are also 2 second-level tables at 0xa0008000 and
         * 0xa0008400.  We will continue to use them until we switch to
-        * our pagetable by setttb().
+        * our pagetable by cpu_setttb().
         */
 
        cpu_domains((DOMAIN_CLIENT << (PMAP_DOMAIN_KERNEL*2)) | DOMAIN_CLIENT);
diff -r fe44dd9102ac -r 658cc755f35f sys/arch/evbarm/ixm1200/ixm1200_machdep.c
--- a/sys/arch/evbarm/ixm1200/ixm1200_machdep.c Mon Dec 28 02:35:20 2009 +0000
+++ b/sys/arch/evbarm/ixm1200/ixm1200_machdep.c Mon Dec 28 03:22:19 2009 +0000
@@ -1,4 +1,4 @@
-/*     $NetBSD: ixm1200_machdep.c,v 1.46 2009/12/26 16:01:24 uebayasi Exp $ */
+/*     $NetBSD: ixm1200_machdep.c,v 1.47 2009/12/28 03:22:20 uebayasi Exp $ */
 
 /*
  * Copyright (c) 2002, 2003
@@ -61,7 +61,7 @@
  */
 
 #include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: ixm1200_machdep.c,v 1.46 2009/12/26 16:01:24 uebayasi Exp $");
+__KERNEL_RCSID(0, "$NetBSD: ixm1200_machdep.c,v 1.47 2009/12/28 03:22:20 uebayasi Exp $");
 
 #include "opt_ddb.h"
 #include "opt_modular.h"
@@ -625,7 +625,7 @@
        /*
         * We must now clean the cache again....
         * Cleaning may be done by reading new data to displace any
-        * dirty data in the cache. This will have happened in setttb()
+        * dirty data in the cache. This will have happened in cpu_setttb()
         * but since we are boot strapping the addresses used for the read
         * may have just been remapped and thus the cache could be out
         * of sync. A re-clean after the switch will cure this.
diff -r fe44dd9102ac -r 658cc755f35f sys/arch/evbarm/lubbock/lubbock_machdep.c
--- a/sys/arch/evbarm/lubbock/lubbock_machdep.c Mon Dec 28 02:35:20 2009 +0000
+++ b/sys/arch/evbarm/lubbock/lubbock_machdep.c Mon Dec 28 03:22:19 2009 +0000
@@ -1,4 +1,4 @@
-/*     $NetBSD: lubbock_machdep.c,v 1.24 2009/12/26 16:01:24 uebayasi Exp $ */
+/*     $NetBSD: lubbock_machdep.c,v 1.25 2009/12/28 03:22:20 uebayasi Exp $ */
 
 /*
  * Copyright (c) 2002, 2003, 2005  Genetec Corporation.  All rights reserved.
@@ -112,7 +112,7 @@
  */
 
 #include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: lubbock_machdep.c,v 1.24 2009/12/26 16:01:24 uebayasi Exp $");
+__KERNEL_RCSID(0, "$NetBSD: lubbock_machdep.c,v 1.25 2009/12/28 03:22:20 uebayasi Exp $");
 
 #include "opt_ddb.h"
 #include "opt_kgdb.h"
@@ -516,7 +516,7 @@
         * RedBoot's first level page table is at 0xa0004000.  There
         * are also 2 second-level tables at 0xa0008000 and
         * 0xa0008400.  We will continue to use them until we switch to
-        * our pagetable by setttb().
+        * our pagetable by cpu_setttb().
         *
         */
 
diff -r fe44dd9102ac -r 658cc755f35f sys/arch/iyonix/iyonix/iyonix_machdep.c
--- a/sys/arch/iyonix/iyonix/iyonix_machdep.c   Mon Dec 28 02:35:20 2009 +0000
+++ b/sys/arch/iyonix/iyonix/iyonix_machdep.c   Mon Dec 28 03:22:19 2009 +0000
@@ -1,4 +1,4 @@
-/*     $NetBSD: iyonix_machdep.c,v 1.15 2009/11/27 03:23:10 rmind Exp $        */
+/*     $NetBSD: iyonix_machdep.c,v 1.16 2009/12/28 03:22:20 uebayasi Exp $     */
 
 /*
  * Copyright (c) 2001, 2002, 2003 Wasabi Systems, Inc.
@@ -73,7 +73,7 @@
  */
 
 #include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: iyonix_machdep.c,v 1.15 2009/11/27 03:23:10 rmind Exp $");
+__KERNEL_RCSID(0, "$NetBSD: iyonix_machdep.c,v 1.16 2009/12/28 03:22:20 uebayasi Exp $");
 
 #include "opt_ddb.h"
 #include "opt_kgdb.h"
@@ -737,7 +737,7 @@
        printf("switching to new L1 page table  @%#lx...", kernel_l1pt.pv_pa);
 #endif
        cpu_domains((DOMAIN_CLIENT << (PMAP_DOMAIN_KERNEL*2)) | DOMAIN_CLIENT);
-       setttb(kernel_l1pt.pv_pa);
+       cpu_setttb(kernel_l1pt.pv_pa);
        cpu_tlb_flushID();
        cpu_domains(DOMAIN_CLIENT << (PMAP_DOMAIN_KERNEL*2));
 
diff -r fe44dd9102ac -r 658cc755f35f sys/arch/netwinder/netwinder/netwinder_machdep.c
--- a/sys/arch/netwinder/netwinder/netwinder_machdep.c  Mon Dec 28 02:35:20 2009 +0000
+++ b/sys/arch/netwinder/netwinder/netwinder_machdep.c  Mon Dec 28 03:22:19 2009 +0000
@@ -1,4 +1,4 @@
-/*     $NetBSD: netwinder_machdep.c,v 1.73 2009/11/27 03:23:11 rmind Exp $     */
+/*     $NetBSD: netwinder_machdep.c,v 1.74 2009/12/28 03:22:20 uebayasi Exp $  */
 
 /*
  * Copyright (c) 1997,1998 Mark Brinicombe.
@@ -40,7 +40,7 @@
  */
 
 #include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: netwinder_machdep.c,v 1.73 2009/11/27 03:23:11 rmind Exp $");
+__KERNEL_RCSID(0, "$NetBSD: netwinder_machdep.c,v 1.74 2009/12/28 03:22:20 uebayasi Exp $");
 
 #include "opt_ddb.h"
 #include "opt_pmap_debug.h"
@@ -695,7 +695,7 @@
 #endif
 
        cpu_domains((DOMAIN_CLIENT << (PMAP_DOMAIN_KERNEL*2)) | DOMAIN_CLIENT);
-       setttb(kernel_l1pt.pv_pa);
+       cpu_setttb(kernel_l1pt.pv_pa);
        cpu_domains(DOMAIN_CLIENT << (PMAP_DOMAIN_KERNEL*2));
 
        /*
diff -r fe44dd9102ac -r 658cc755f35f sys/arch/zaurus/zaurus/machdep.c
--- a/sys/arch/zaurus/zaurus/machdep.c  Mon Dec 28 02:35:20 2009 +0000
+++ b/sys/arch/zaurus/zaurus/machdep.c  Mon Dec 28 03:22:19 2009 +0000
@@ -1,4 +1,4 @@
-/*     $NetBSD: machdep.c,v 1.19 2009/11/27 03:23:15 rmind Exp $       */
+/*     $NetBSD: machdep.c,v 1.20 2009/12/28 03:22:20 uebayasi Exp $    */
 /*     $OpenBSD: zaurus_machdep.c,v 1.25 2006/06/20 18:24:04 todd Exp $        */
 
 /*
@@ -107,7 +107,7 @@
  */
 
 #include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: machdep.c,v 1.19 2009/11/27 03:23:15 rmind Exp $");
+__KERNEL_RCSID(0, "$NetBSD: machdep.c,v 1.20 2009/12/28 03:22:20 uebayasi Exp $");
 
 #include "opt_ddb.h"
 #include "opt_kgdb.h"
@@ -984,7 +984,7 @@
 #endif
 
        cpu_domains((DOMAIN_CLIENT << (PMAP_DOMAIN_KERNEL*2)) | DOMAIN_CLIENT);
-       setttb(kernel_l1pt.pv_pa);
+       cpu_setttb(kernel_l1pt.pv_pa);
        cpu_tlb_flushID();
        cpu_domains(DOMAIN_CLIENT << (PMAP_DOMAIN_KERNEL*2));
 



Home | Main Index | Thread Index | Old Index
diff -r fe44dd9102ac -r 658cc755f35f sys/arch/acorn32/acorn32/rpc_machdep.c
--- a/sys/arch/acorn32/acorn32/rpc_machdep.c    Mon Dec 28 02:35:20 2009 +0000
+++ b/sys/arch/acorn32/acorn32/rpc_machdep.c    Mon Dec 28 03:22:19 2009 +0000
@@ -1,4 +1,4 @@
-/*     $NetBSD: rpc_machdep.c,v 1.79 2009/11/27 03:23:03 rmind Exp $   */
+/*     $NetBSD: rpc_machdep.c,v 1.80 2009/12/28 03:22:19 uebayasi Exp $        */
 
 /*
  * Copyright (c) 2000-2002 Reinoud Zandijk.
@@ -55,7 +55,7 @@
 
 #include <sys/param.h>
 
-__KERNEL_RCSID(0, "$NetBSD: rpc_machdep.c,v 1.79 2009/11/27 03:23:03 rmind Exp $");
+__KERNEL_RCSID(0, "$NetBSD: rpc_machdep.c,v 1.80 2009/12/28 03:22:19 uebayasi Exp $");
 
 #include <sys/systm.h>
 #include <sys/kernel.h>
@@ -821,12 +821,12 @@
        printf("switching to new L1 page table\n");
 #endif
 
-       setttb(kernel_l1pt.pv_pa);
+       cpu_setttb(kernel_l1pt.pv_pa);
 
        /*
         * We must now clean the cache again....
         * Cleaning may be done by reading new data to displace any
         * dirty data in the cache. This will have happened in setttb()
         * but since we are boot strapping the addresses used for the read
         * may have just been remapped and thus the cache could be out
         * of sync. A re-clean after the switch will cure this.
@@ -821,12 +821,12 @@
         * We must now clean the cache again....
         * Cleaning may be done by reading new data to displace any
-        * dirty data in the cache. This will have happened in setttb()
+        * dirty data in the cache. This will have happened in cpu_setttb()
         * but since we are boot strapping the addresses used for the read
         * may have just been remapped and thus the cache could be out
diff -r fe44dd9102ac -r 658cc755f35f sys/arch/acorn32/eb7500atx/eb7500atx_machdep.c
--- a/sys/arch/acorn32/eb7500atx/eb7500atx_machdep.c    Mon Dec 28 02:35:20 2009 +0000
+++ b/sys/arch/acorn32/eb7500atx/eb7500atx_machdep.c    Mon Dec 28 03:22:19 2009 +0000
@@ -1,4 +1,4 @@
-/*     $NetBSD: eb7500atx_machdep.c,v 1.18 2009/11/27 03:23:03 rmind Exp $     */
+/*     $NetBSD: eb7500atx_machdep.c,v 1.19 2009/12/28 03:22:19 uebayasi Exp $  */
 
 /*
  * Copyright (c) 2000-2002 Reinoud Zandijk.
@@ -55,7 +55,7 @@
 
 #include <sys/param.h>
 
-__KERNEL_RCSID(0, "$NetBSD: eb7500atx_machdep.c,v 1.18 2009/11/27 03:23:03 rmind Exp $");
+__KERNEL_RCSID(0, "$NetBSD: eb7500atx_machdep.c,v 1.19 2009/12/28 03:22:19 uebayasi Exp $");
 
 #include <sys/systm.h>
 #include <sys/kernel.h>
@@ -761,12 +761,12 @@
 #ifdef VERBOSE_INIT_ARM
        printf("switching to new L1 page table\n");
 #endif
-       setttb(kernel_l1pt.pv_pa);
+       cpu_setttb(kernel_l1pt.pv_pa);
 
        /*
         * We must now clean the cache again....
         * Cleaning may be done by reading new data to displace any
         * dirty data in the cache. This will have happened in setttb()
         * but since we are boot strapping the addresses used for the read
         * may have just been remapped and thus the cache could be out
         * of sync. A re-clean after the switch will cure this.
@@ -761,12 +761,12 @@
         * We must now clean the cache again....
         * Cleaning may be done by reading new data to displace any
-        * dirty data in the cache. This will have happened in setttb()
+        * dirty data in the cache. This will have happened in cpu_setttb()
         * but since we are boot strapping the addresses used for the read
         * may have just been remapped and thus the cache could be out
diff -r fe44dd9102ac -r 658cc755f35f sys/arch/shark/ofw/ofw.c
--- a/sys/arch/shark/ofw/ofw.c  Mon Dec 28 02:35:20 2009 +0000
+++ b/sys/arch/shark/ofw/ofw.c  Mon Dec 28 03:22:19 2009 +0000
@@ -1,4 +1,4 @@
-/*     $NetBSD: ofw.c,v 1.52 2009/11/27 03:23:13 rmind Exp $   */
+/*     $NetBSD: ofw.c,v 1.53 2009/12/28 03:22:20 uebayasi Exp $        */
 
 /*
  * Copyright 1997
@@ -41,7 +41,7 @@
  */
 
 #include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: ofw.c,v 1.52 2009/11/27 03:23:13 rmind Exp $");
+__KERNEL_RCSID(0, "$NetBSD: ofw.c,v 1.53 2009/12/28 03:22:20 uebayasi Exp $");
 
 #include <sys/param.h>
 #include <sys/systm.h>
@@ -746,7 +746,7 @@
  *  and poking them into the new page tables.  We then notify OFW
  *  that we are assuming control of memory-management by installing
  *  our callback-handler, and switch to the NetBSD-managed page
  *  tables with the setttb() call.
  *  
  *  This scheme may cause some amount of memory to be wasted within
  *  OFW as dead page tables, but it shouldn't be more than about 
@@ -780,7 +780,7 @@
 
        /* Switch to the proc0 pagetables. */
        cpu_domains((DOMAIN_CLIENT << (PMAP_DOMAIN_KERNEL*2)) | DOMAIN_CLIENT);
-       setttb(kernel_l1pt.pv_pa);
+       cpu_setttb(kernel_l1pt.pv_pa);
        cpu_tlb_flushID();
        cpu_domains(DOMAIN_CLIENT << (PMAP_DOMAIN_KERNEL*2));
 
@@ -746,7 +746,7 @@
  *  that we are assuming control of memory-management by installing
  *  our callback-handler, and switch to the NetBSD-managed page
- *  tables with the setttb() call.
+ *  tables with the cpu_setttb() call.
  *  
  *  This scheme may cause some amount of memory to be wasted within